#!/bin/sh
### BEGIN INIT INFO
# Provides:          SickBeard-daemon
# Required-Start:    $local_fs $remote_fs $network
# Required-Stop:     $local_fs $remote_fs $network
# Default-Start:     2 3 4 5
# Default-Stop:      0 1 6
# Short-Description: Start or stop the SABnzbd-daemon.
### END INIT INFO

PKG_NAME="SickBeard"
PKG_DIR="/usr/local/AppCentral/sickbeard"
RUN_AS="admin:administrators"
CONFIG_DIR="$PKG_DIR/config"
REPOS_DIR="$PKG_DIR/repository"
PID_FILE="$PKG_DIR/$PKG_NAME.pid"
DAEMON="/usr/local/bin/python2.7 SickBeard.py"
DAEMON_PACKAGE="/usr/local/AppCentral/python/lib/python2.7/site-packages" #change according to daemon version used
DAEMON_OPTS=" --daemon --datadir $PKG_DIR/config --pidfile $PID_FILE"
GIT_URL="git://github.com/midgetspy/Sick-Beard.git"
GIT_URL1="http://github.com/midgetspy/Sick-Beard.git"
export PYTHON_EGG_CACHE=/volume1/home/admin/.python-eggs 
ARCH=$(/bin/uname -m)
if [ "$ARCH" = "x86_64" ]; then
	PY_DIR="$REPOS_DIR/python"
elif [ "$ARCH" = "armv7l" ]; then
	PY_DIR="$REPOS_DIR/python-arm"
else
	PY_DIR="$REPOS_DIR/python-32"
fi
export PYTHONPATH="$PY_DIR:$PYTHONPATH" 

WriteIni() { #writes a value to a parameter in a section in a file
        local SECTION=$1
        local PARAM=$2
        local VALUE=$3
        local FILE=$4
        /bin/sed -ie "/^\[${SECTION}\]/,/^\[.*\]/s|^\(${PARAM}[ \t]*=[ \t]*\).*$|\1${VALUE}|" ${FILE}
}
                                        
ReadIni() { #reads a value from a parameter in a section in a file
        local SECTION=$1
        local PARAM=$2
        local FILE=$3
        /bin/echo $(/bin/sed -n "/^\[${SECTION}\]/,/^\[.*\]/s/^${PARAM}[ \t]*=[ \t]*\(.*$\)/\1/p" ${FILE})
}

WriteDefaults() { #Write the default values to a bog standard config file (fresh install only)
        /bin/echo -n " Writing default values to the config file..."
        
        local CONFIGFILE=$CONFIG_DIR/config.ini
              
        [ -f $CONFIGFILE ] || /bin/cp $CONFIGFILE.org $CONFIGFILE
                
        WriteIni General web_port 7071 $CONFIGFILE
        WriteIni General web_host 0.0.0.0 $CONFIGFILE
        WriteIni General git_path "/usr/local/bin/git" $CONFIGFILE
        /bin/echo  " Done"
}

                                                                        
CheckPkgRunning() { #Is the PKG already running? if so, exit the script
      [ -f $PID_FILE ] && /sbin/start-stop-daemon -K --test -q -p $PID_FILE -x ${DAEMON} && /bin/echo " $PKG_NAME is already running" && exit 1
	#ok, we survived so the PKG should not be running
} 

StartPkg(){ #starts the PKG
	/bin/echo -n "Starting $PKG_NAME"
	[ -d $PYTHON_EGG_CACHE ] || /bin/mkdir $PYTHON_EGG_CACHE  
	[ -d $PKG_DIR/$PKG_NAME/.git ] || /usr/local/bin/git clone $GIT_URL $PKG_DIR/$PKG_NAME || /usr/local/bin/git clone $GIT_URL1 $PKG_DIR/$PKG_NAME 
	[ -f $CONFIG_DIR/config.ini ] || WriteDefaults #creates and writes the default config file on a fresh install
	/bin/chown -R $RUN_AS $PKG_DIR
	/bin/chown -R $RUN_AS $PYTHON_EGG_CACHE
	/bin/chmod -R -t $PKG_DIR # make sure no system bits are set.
	/bin/chmod -R -s $PKG_DIR # make sure no system bits are set.
	cd $PKG_DIR/$PKG_NAME
	/sbin/start-stop-daemon -S -n $PKG_NAME -p $PID_FILE -c $RUN_AS -x ${DAEMON} --${DAEMON_OPTS}
	/bin/echo " Done ($(/bin/date))"
}

ShutdownPkg() { #kills a proces based on a PID in a given PID file
	if [ -f $PID_FILE ] && /sbin/start-stop-daemon -K --test -q -p $PID_FILE -x ${DAEMON}; then
		#grab pid from pid file
		Pid=$(/bin/cat $PID_FILE)
		i=0
		/sbin/start-stop-daemon -K -q -p $PID_FILE -x ${DAEMON}
		/bin/echo -n " Waiting for ${PKG_NAME} to shut down: "
		while [ -d /proc/$Pid ]; do
			sleep 1
			let i+=1
			/bin/echo -n "$i, "
			if [ $i = 45 ]; then
				/bin/echo -n " Tired of waiting, killing ${PKG_NAME} now"
				/bin/kill -9 $Pid
				/bin/rm -f $PID_FILE
				/bin/echo " Done ($(/bin/date))"
				exit 1
			fi
		done
		/bin/rm -f $PID_FILE
		/bin/echo "Done ($(/bin/date))"
	else
		/bin/echo "${PKG_NAME} is not running? ($(/bin/date))"
	fi
}

case "$1" in
	start)
		/bin/echo "$PKG_NAME prestartup checks... ($(/bin/date))"	
		CheckPkgRunning  #Check if the PKG is not running, else exit
		StartPkg	 #Start the PKG... (finaly ;) )
	;;
	stop)
		/bin/echo "Shutting down ${PKG_NAME} at $(/bin/date)... "
		ShutdownPkg 	#shutdown the package
	;;
	restart)
		echo "Restarting $PKG_NAME"
		$0 stop
		$0 start
	;;
	*)
		echo "Usage: $0 {start|stop|restart}"
esac

exit 0

